@@ -23,7 +23,7 @@
 #  include <config.h>
 #endif
 
-/*#include <gnome.h>*/
+#include <string.h>
 #include <gtk/gtkgl.h>
 #include "callbacks.h"
 #include "glview.h"
