@@ -44,8 +44,8 @@ extern GtkWidget *glview;
 extern MiauiLandmarkTable *landmarktable; 
 extern float iso_value_max; 
 extern float iso_value_min; 
-GtkRange *range_iso_value_max; 
-GtkRange *range_iso_value_min; 
+extern GtkRange *range_iso_value_max; 
+extern GtkRange *range_iso_value_min; 
 extern const char *in_filename; 
 extern const char *lm_filename; 
 extern const char *out_filename;
