@@ -408,15 +408,15 @@ static const char *__fragment_program[] = {
 	"uniform float alpha_discard_min;\n"
 	"void main(void)\n",
 	"{\n",
-	"  float alpha = texture3D(VolumeTexture, gl_TexCoord[0]).a;\n", //getting the Normal/Value Values,
+	"  float alpha = texture3D(VolumeTexture, gl_TexCoord[0].xyz).a;\n", //getting the Normal/Value Values,
 	"  if (alpha > alpha_discard_max || alpha < alpha_discard_min) discard;\n", 
 	//computing SurfaceNormal
-	"  float nx = GradientScale.x * (texture3D(VolumeTexture, gl_TexCoord[1]).a - alpha);\n",
-	"  float ny = GradientScale.y * (texture3D(VolumeTexture, gl_TexCoord[2]).a - alpha);\n",
-	"  float nz = GradientScale.z * (texture3D(VolumeTexture, gl_TexCoord[3]).a - alpha);\n",
+	"  float nx = GradientScale.x * (texture3D(VolumeTexture, gl_TexCoord[1].xyz).a - alpha);\n",
+	"  float ny = GradientScale.y * (texture3D(VolumeTexture, gl_TexCoord[2].xyz).a - alpha);\n",
+	"  float nz = GradientScale.z * (texture3D(VolumeTexture, gl_TexCoord[3].xyz).a - alpha);\n",
 	"  vec3 Norm = normalize(vec3(nx, ny, nz));",          
 	"  float LightIntens =  max(dot(LightDirection, Norm),0.0);",     //computing Light Intensity
-	"  gl_FragColor = vec4(LightIntens.xxx, alpha);",               //setting Fragmentcolor
+	"  gl_FragColor = vec4(LightIntens, LightIntens, LightIntens, alpha);",               //setting Fragmentcolor
 	"}\n"
 };	
 
